pub mod _domain_v2beta1_dns_zones__dns_zone__import_provider_online_v1;
pub use self::_domain_v2beta1_dns_zones__dns_zone__import_provider_online_v1::DomainV2beta1DnsZonesDnsZoneImportProviderOnlineV1;
pub mod inline_object;
pub use self::inline_object::InlineObject;
pub mod inline_object_1;
pub use self::inline_object_1::InlineObject1;
pub mod inline_object_10;
pub use self::inline_object_10::InlineObject10;
pub mod inline_object_11;
pub use self::inline_object_11::InlineObject11;
pub mod inline_object_12;
pub use self::inline_object_12::InlineObject12;
pub mod inline_object_13;
pub use self::inline_object_13::InlineObject13;
pub mod inline_object_14;
pub use self::inline_object_14::InlineObject14;
pub mod inline_object_15;
pub use self::inline_object_15::InlineObject15;
pub mod inline_object_16;
pub use self::inline_object_16::InlineObject16;
pub mod inline_object_17;
pub use self::inline_object_17::InlineObject17;
pub mod inline_object_18;
pub use self::inline_object_18::InlineObject18;
pub mod inline_object_19;
pub use self::inline_object_19::InlineObject19;
pub mod inline_object_2;
pub use self::inline_object_2::InlineObject2;
pub mod inline_object_20;
pub use self::inline_object_20::InlineObject20;
pub mod inline_object_21;
pub use self::inline_object_21::InlineObject21;
pub mod inline_object_22;
pub use self::inline_object_22::InlineObject22;
pub mod inline_object_23;
pub use self::inline_object_23::InlineObject23;
pub mod inline_object_24;
pub use self::inline_object_24::InlineObject24;
pub mod inline_object_25;
pub use self::inline_object_25::InlineObject25;
pub mod inline_object_26;
pub use self::inline_object_26::InlineObject26;
pub mod inline_object_27;
pub use self::inline_object_27::InlineObject27;
pub mod inline_object_28;
pub use self::inline_object_28::InlineObject28;
pub mod inline_object_29;
pub use self::inline_object_29::InlineObject29;
pub mod inline_object_3;
pub use self::inline_object_3::InlineObject3;
pub mod inline_object_30;
pub use self::inline_object_30::InlineObject30;
pub mod inline_object_31;
pub use self::inline_object_31::InlineObject31;
pub mod inline_object_32;
pub use self::inline_object_32::InlineObject32;
pub mod inline_object_33;
pub use self::inline_object_33::InlineObject33;
pub mod inline_object_34;
pub use self::inline_object_34::InlineObject34;
pub mod inline_object_35;
pub use self::inline_object_35::InlineObject35;
pub mod inline_object_36;
pub use self::inline_object_36::InlineObject36;
pub mod inline_object_37;
pub use self::inline_object_37::InlineObject37;
pub mod inline_object_38;
pub use self::inline_object_38::InlineObject38;
pub mod inline_object_39;
pub use self::inline_object_39::InlineObject39;
pub mod inline_object_4;
pub use self::inline_object_4::InlineObject4;
pub mod inline_object_40;
pub use self::inline_object_40::InlineObject40;
pub mod inline_object_41;
pub use self::inline_object_41::InlineObject41;
pub mod inline_object_42;
pub use self::inline_object_42::InlineObject42;
pub mod inline_object_43;
pub use self::inline_object_43::InlineObject43;
pub mod inline_object_44;
pub use self::inline_object_44::InlineObject44;
pub mod inline_object_45;
pub use self::inline_object_45::InlineObject45;
pub mod inline_object_46;
pub use self::inline_object_46::InlineObject46;
pub mod inline_object_47;
pub use self::inline_object_47::InlineObject47;
pub mod inline_object_48;
pub use self::inline_object_48::InlineObject48;
pub mod inline_object_49;
pub use self::inline_object_49::InlineObject49;
pub mod inline_object_5;
pub use self::inline_object_5::InlineObject5;
pub mod inline_object_50;
pub use self::inline_object_50::InlineObject50;
pub mod inline_object_51;
pub use self::inline_object_51::InlineObject51;
pub mod inline_object_52;
pub use self::inline_object_52::InlineObject52;
pub mod inline_object_53;
pub use self::inline_object_53::InlineObject53;
pub mod inline_object_54;
pub use self::inline_object_54::InlineObject54;
pub mod inline_object_6;
pub use self::inline_object_6::InlineObject6;
pub mod inline_object_7;
pub use self::inline_object_7::InlineObject7;
pub mod inline_object_8;
pub use self::inline_object_8::InlineObject8;
pub mod inline_object_9;
pub use self::inline_object_9::InlineObject9;
pub mod _k8s_v1_regions__region__clusters_auto_upgrade;
pub use self::_k8s_v1_regions__region__clusters_auto_upgrade::K8sV1RegionsRegionClustersAutoUpgrade;
pub mod _k8s_v1_regions__region__clusters_auto_upgrade_maintenance_window;
pub use self::_k8s_v1_regions__region__clusters_auto_upgrade_maintenance_window::K8sV1RegionsRegionClustersAutoUpgradeMaintenanceWindow;
pub mod _k8s_v1_regions__region__clusters_autoscaler_config;
pub use self::_k8s_v1_regions__region__clusters_autoscaler_config::K8sV1RegionsRegionClustersAutoscalerConfig;
pub mod _k8s_v1_regions__region__clusters_autoscaler_config_scale_down_utilization_threshold;
pub use self::_k8s_v1_regions__region__clusters_autoscaler_config_scale_down_utilization_threshold::K8sV1RegionsRegionClustersAutoscalerConfigScaleDownUtilizationThreshold;
pub mod _k8s_v1_regions__region__clusters__cluster_id__auto_upgrade;
pub use self::_k8s_v1_regions__region__clusters__cluster_id__auto_upgrade::K8sV1RegionsRegionClustersClusterIdAutoUpgrade;
pub mod _k8s_v1_regions__region__clusters__cluster_id__autoscaler_config;
pub use self::_k8s_v1_regions__region__clusters__cluster_id__autoscaler_config::K8sV1RegionsRegionClustersClusterIdAutoscalerConfig;
pub mod _k8s_v1_regions__region__clusters__cluster_id__open_id_connect_config;
pub use self::_k8s_v1_regions__region__clusters__cluster_id__open_id_connect_config::K8sV1RegionsRegionClustersClusterIdOpenIdConnectConfig;
pub mod _k8s_v1_regions__region__clusters__cluster_id__pools_upgrade_policy;
pub use self::_k8s_v1_regions__region__clusters__cluster_id__pools_upgrade_policy::K8sV1RegionsRegionClustersClusterIdPoolsUpgradePolicy;
pub mod _k8s_v1_regions__region__clusters_open_id_connect_config;
pub use self::_k8s_v1_regions__region__clusters_open_id_connect_config::K8sV1RegionsRegionClustersOpenIdConnectConfig;
pub mod _k8s_v1_regions__region__pools__pool_id__kubelet_args;
pub use self::_k8s_v1_regions__region__pools__pool_id__kubelet_args::K8sV1RegionsRegionPoolsPoolIdKubeletArgs;
pub mod scaleway_baremetal_v1_bmc_access;
pub use self::scaleway_baremetal_v1_bmc_access::ScalewayBaremetalV1BmcAccess;
pub mod scaleway_baremetal_v1_cpu;
pub use self::scaleway_baremetal_v1_cpu::ScalewayBaremetalV1Cpu;
pub mod scaleway_baremetal_v1_create_server_request_install;
pub use self::scaleway_baremetal_v1_create_server_request_install::ScalewayBaremetalV1CreateServerRequestInstall;
pub mod scaleway_baremetal_v1_disk;
pub use self::scaleway_baremetal_v1_disk::ScalewayBaremetalV1Disk;
pub mod scaleway_baremetal_v1_get_server_metrics_response;
pub use self::scaleway_baremetal_v1_get_server_metrics_response::ScalewayBaremetalV1GetServerMetricsResponse;
pub mod scaleway_baremetal_v1_get_server_metrics_response_pings;
pub use self::scaleway_baremetal_v1_get_server_metrics_response_pings::ScalewayBaremetalV1GetServerMetricsResponsePings;
pub mod scaleway_baremetal_v1_ip;
pub use self::scaleway_baremetal_v1_ip::ScalewayBaremetalV1Ip;
pub mod scaleway_baremetal_v1_list_offers_response;
pub use self::scaleway_baremetal_v1_list_offers_response::ScalewayBaremetalV1ListOffersResponse;
pub mod scaleway_baremetal_v1_list_os_response;
pub use self::scaleway_baremetal_v1_list_os_response::ScalewayBaremetalV1ListOsResponse;
pub mod scaleway_baremetal_v1_list_server_events_response;
pub use self::scaleway_baremetal_v1_list_server_events_response::ScalewayBaremetalV1ListServerEventsResponse;
pub mod scaleway_baremetal_v1_list_servers_response;
pub use self::scaleway_baremetal_v1_list_servers_response::ScalewayBaremetalV1ListServersResponse;
pub mod scaleway_baremetal_v1_memory;
pub use self::scaleway_baremetal_v1_memory::ScalewayBaremetalV1Memory;
pub mod scaleway_baremetal_v1_offer;
pub use self::scaleway_baremetal_v1_offer::ScalewayBaremetalV1Offer;
pub mod scaleway_baremetal_v1_offer_price_per_hour;
pub use self::scaleway_baremetal_v1_offer_price_per_hour::ScalewayBaremetalV1OfferPricePerHour;
pub mod scaleway_baremetal_v1_offer_price_per_month;
pub use self::scaleway_baremetal_v1_offer_price_per_month::ScalewayBaremetalV1OfferPricePerMonth;
pub mod scaleway_baremetal_v1_os;
pub use self::scaleway_baremetal_v1_os::ScalewayBaremetalV1Os;
pub mod scaleway_baremetal_v1_persistent_memory;
pub use self::scaleway_baremetal_v1_persistent_memory::ScalewayBaremetalV1PersistentMemory;
pub mod scaleway_baremetal_v1_raid_controller;
pub use self::scaleway_baremetal_v1_raid_controller::ScalewayBaremetalV1RaidController;
pub mod scaleway_baremetal_v1_server;
pub use self::scaleway_baremetal_v1_server::ScalewayBaremetalV1Server;
pub mod scaleway_baremetal_v1_server_event;
pub use self::scaleway_baremetal_v1_server_event::ScalewayBaremetalV1ServerEvent;
pub mod scaleway_baremetal_v1_server_install;
pub use self::scaleway_baremetal_v1_server_install::ScalewayBaremetalV1ServerInstall;
pub mod scaleway_baremetal_v1_server_install_status;
pub use self::scaleway_baremetal_v1_server_install_status::ScalewayBaremetalV1ServerInstallStatus;
pub mod scaleway_domain_v2beta1_dns_zone;
pub use self::scaleway_domain_v2beta1_dns_zone::ScalewayDomainV2beta1DnsZone;
pub mod scaleway_domain_v2beta1_dns_zone_status;
pub use self::scaleway_domain_v2beta1_dns_zone_status::ScalewayDomainV2beta1DnsZoneStatus;
pub mod scaleway_domain_v2beta1_dns_zone_version;
pub use self::scaleway_domain_v2beta1_dns_zone_version::ScalewayDomainV2beta1DnsZoneVersion;
pub mod scaleway_domain_v2beta1_get_dns_zone_tsig_key_response;
pub use self::scaleway_domain_v2beta1_get_dns_zone_tsig_key_response::ScalewayDomainV2beta1GetDnsZoneTsigKeyResponse;
pub mod scaleway_domain_v2beta1_get_dns_zone_version_diff_response;
pub use self::scaleway_domain_v2beta1_get_dns_zone_version_diff_response::ScalewayDomainV2beta1GetDnsZoneVersionDiffResponse;
pub mod scaleway_domain_v2beta1_import_provider_dns_zone_response;
pub use self::scaleway_domain_v2beta1_import_provider_dns_zone_response::ScalewayDomainV2beta1ImportProviderDnsZoneResponse;
pub mod scaleway_domain_v2beta1_import_raw_dns_zone_response;
pub use self::scaleway_domain_v2beta1_import_raw_dns_zone_response::ScalewayDomainV2beta1ImportRawDnsZoneResponse;
pub mod scaleway_domain_v2beta1_list_dns_zone_nameservers_response;
pub use self::scaleway_domain_v2beta1_list_dns_zone_nameservers_response::ScalewayDomainV2beta1ListDnsZoneNameserversResponse;
pub mod scaleway_domain_v2beta1_list_dns_zone_records_response;
pub use self::scaleway_domain_v2beta1_list_dns_zone_records_response::ScalewayDomainV2beta1ListDnsZoneRecordsResponse;
pub mod scaleway_domain_v2beta1_list_dns_zone_version_records_response;
pub use self::scaleway_domain_v2beta1_list_dns_zone_version_records_response::ScalewayDomainV2beta1ListDnsZoneVersionRecordsResponse;
pub mod scaleway_domain_v2beta1_list_dns_zone_versions_response;
pub use self::scaleway_domain_v2beta1_list_dns_zone_versions_response::ScalewayDomainV2beta1ListDnsZoneVersionsResponse;
pub mod scaleway_domain_v2beta1_list_dns_zones_response;
pub use self::scaleway_domain_v2beta1_list_dns_zones_response::ScalewayDomainV2beta1ListDnsZonesResponse;
pub mod scaleway_domain_v2beta1_list_ssl_certificates_response;
pub use self::scaleway_domain_v2beta1_list_ssl_certificates_response::ScalewayDomainV2beta1ListSslCertificatesResponse;
pub mod scaleway_domain_v2beta1_nameserver;
pub use self::scaleway_domain_v2beta1_nameserver::ScalewayDomainV2beta1Nameserver;
pub mod scaleway_domain_v2beta1_raw_format;
pub use self::scaleway_domain_v2beta1_raw_format::ScalewayDomainV2beta1RawFormat;
pub mod scaleway_domain_v2beta1_record;
pub use self::scaleway_domain_v2beta1_record::ScalewayDomainV2beta1Record;
pub mod scaleway_domain_v2beta1_record_change;
pub use self::scaleway_domain_v2beta1_record_change::ScalewayDomainV2beta1RecordChange;
pub mod scaleway_domain_v2beta1_record_change_add;
pub use self::scaleway_domain_v2beta1_record_change_add::ScalewayDomainV2beta1RecordChangeAdd;
pub mod scaleway_domain_v2beta1_record_change_delete;
pub use self::scaleway_domain_v2beta1_record_change_delete::ScalewayDomainV2beta1RecordChangeDelete;
pub mod scaleway_domain_v2beta1_record_change_set;
pub use self::scaleway_domain_v2beta1_record_change_set::ScalewayDomainV2beta1RecordChangeSet;
pub mod scaleway_domain_v2beta1_record_change_set_id_fields;
pub use self::scaleway_domain_v2beta1_record_change_set_id_fields::ScalewayDomainV2beta1RecordChangeSetIdFields;
pub mod scaleway_domain_v2beta1_record_geo_ip_config;
pub use self::scaleway_domain_v2beta1_record_geo_ip_config::ScalewayDomainV2beta1RecordGeoIpConfig;
pub mod scaleway_domain_v2beta1_record_geo_ip_config_match;
pub use self::scaleway_domain_v2beta1_record_geo_ip_config_match::ScalewayDomainV2beta1RecordGeoIpConfigMatch;
pub mod scaleway_domain_v2beta1_record_http_service_config;
pub use self::scaleway_domain_v2beta1_record_http_service_config::ScalewayDomainV2beta1RecordHttpServiceConfig;
pub mod scaleway_domain_v2beta1_record_http_service_config_strategy;
pub use self::scaleway_domain_v2beta1_record_http_service_config_strategy::ScalewayDomainV2beta1RecordHttpServiceConfigStrategy;
pub mod scaleway_domain_v2beta1_record_type;
pub use self::scaleway_domain_v2beta1_record_type::ScalewayDomainV2beta1RecordType;
pub mod scaleway_domain_v2beta1_record_view_config;
pub use self::scaleway_domain_v2beta1_record_view_config::ScalewayDomainV2beta1RecordViewConfig;
pub mod scaleway_domain_v2beta1_record_view_config_view;
pub use self::scaleway_domain_v2beta1_record_view_config_view::ScalewayDomainV2beta1RecordViewConfigView;
pub mod scaleway_domain_v2beta1_record_weighted_config;
pub use self::scaleway_domain_v2beta1_record_weighted_config::ScalewayDomainV2beta1RecordWeightedConfig;
pub mod scaleway_domain_v2beta1_record_weighted_config_weighted_ip;
pub use self::scaleway_domain_v2beta1_record_weighted_config_weighted_ip::ScalewayDomainV2beta1RecordWeightedConfigWeightedIp;
pub mod scaleway_domain_v2beta1_refresh_dns_zone_response;
pub use self::scaleway_domain_v2beta1_refresh_dns_zone_response::ScalewayDomainV2beta1RefreshDnsZoneResponse;
pub mod scaleway_domain_v2beta1_ssl_certificate;
pub use self::scaleway_domain_v2beta1_ssl_certificate::ScalewayDomainV2beta1SslCertificate;
pub mod scaleway_domain_v2beta1_ssl_certificate_status;
pub use self::scaleway_domain_v2beta1_ssl_certificate_status::ScalewayDomainV2beta1SslCertificateStatus;
pub mod scaleway_domain_v2beta1_update_dns_zone_nameservers_response;
pub use self::scaleway_domain_v2beta1_update_dns_zone_nameservers_response::ScalewayDomainV2beta1UpdateDnsZoneNameserversResponse;
pub mod scaleway_domain_v2beta1_update_dns_zone_records_response;
pub use self::scaleway_domain_v2beta1_update_dns_zone_records_response::ScalewayDomainV2beta1UpdateDnsZoneRecordsResponse;
pub mod scaleway_flexible_ip_v1alpha1_attach_flexible_ips_response;
pub use self::scaleway_flexible_ip_v1alpha1_attach_flexible_ips_response::ScalewayFlexibleIpV1alpha1AttachFlexibleIpsResponse;
pub mod scaleway_flexible_ip_v1alpha1_detach_flexible_ips_response;
pub use self::scaleway_flexible_ip_v1alpha1_detach_flexible_ips_response::ScalewayFlexibleIpV1alpha1DetachFlexibleIpsResponse;
pub mod scaleway_flexible_ip_v1alpha1_flexible_ip;
pub use self::scaleway_flexible_ip_v1alpha1_flexible_ip::ScalewayFlexibleIpV1alpha1FlexibleIp;
pub mod scaleway_flexible_ip_v1alpha1_flexible_ip_mac_address;
pub use self::scaleway_flexible_ip_v1alpha1_flexible_ip_mac_address::ScalewayFlexibleIpV1alpha1FlexibleIpMacAddress;
pub mod scaleway_flexible_ip_v1alpha1_flexible_ip_status;
pub use self::scaleway_flexible_ip_v1alpha1_flexible_ip_status::ScalewayFlexibleIpV1alpha1FlexibleIpStatus;
pub mod scaleway_flexible_ip_v1alpha1_list_flexible_ips_response;
pub use self::scaleway_flexible_ip_v1alpha1_list_flexible_ips_response::ScalewayFlexibleIpV1alpha1ListFlexibleIpsResponse;
pub mod scaleway_flexible_ip_v1alpha1_mac_address_status;
pub use self::scaleway_flexible_ip_v1alpha1_mac_address_status::ScalewayFlexibleIpV1alpha1MacAddressStatus;
pub mod scaleway_flexible_ip_v1alpha1_mac_address_type;
pub use self::scaleway_flexible_ip_v1alpha1_mac_address_type::ScalewayFlexibleIpV1alpha1MacAddressType;
pub mod scaleway_k8s_v1_cluster;
pub use self::scaleway_k8s_v1_cluster::ScalewayK8sV1Cluster;
pub mod scaleway_k8s_v1_cluster_auto_upgrade;
pub use self::scaleway_k8s_v1_cluster_auto_upgrade::ScalewayK8sV1ClusterAutoUpgrade;
pub mod scaleway_k8s_v1_cluster_autoscaler_config;
pub use self::scaleway_k8s_v1_cluster_autoscaler_config::ScalewayK8sV1ClusterAutoscalerConfig;
pub mod scaleway_k8s_v1_cluster_open_id_connect_config;
pub use self::scaleway_k8s_v1_cluster_open_id_connect_config::ScalewayK8sV1ClusterOpenIdConnectConfig;
pub mod scaleway_k8s_v1_cni;
pub use self::scaleway_k8s_v1_cni::ScalewayK8sV1Cni;
pub mod scaleway_k8s_v1_create_cluster_request_pool_config;
pub use self::scaleway_k8s_v1_create_cluster_request_pool_config::ScalewayK8sV1CreateClusterRequestPoolConfig;
pub mod scaleway_k8s_v1_create_cluster_request_pool_config_upgrade_policy;
pub use self::scaleway_k8s_v1_create_cluster_request_pool_config_upgrade_policy::ScalewayK8sV1CreateClusterRequestPoolConfigUpgradePolicy;
pub mod scaleway_k8s_v1_ingress;
pub use self::scaleway_k8s_v1_ingress::ScalewayK8sV1Ingress;
pub mod scaleway_k8s_v1_list_cluster_available_versions_response;
pub use self::scaleway_k8s_v1_list_cluster_available_versions_response::ScalewayK8sV1ListClusterAvailableVersionsResponse;
pub mod scaleway_k8s_v1_list_clusters_response;
pub use self::scaleway_k8s_v1_list_clusters_response::ScalewayK8sV1ListClustersResponse;
pub mod scaleway_k8s_v1_list_nodes_response;
pub use self::scaleway_k8s_v1_list_nodes_response::ScalewayK8sV1ListNodesResponse;
pub mod scaleway_k8s_v1_list_pools_response;
pub use self::scaleway_k8s_v1_list_pools_response::ScalewayK8sV1ListPoolsResponse;
pub mod scaleway_k8s_v1_list_versions_response;
pub use self::scaleway_k8s_v1_list_versions_response::ScalewayK8sV1ListVersionsResponse;
pub mod scaleway_k8s_v1_node;
pub use self::scaleway_k8s_v1_node::ScalewayK8sV1Node;
pub mod scaleway_k8s_v1_pool;
pub use self::scaleway_k8s_v1_pool::ScalewayK8sV1Pool;
pub mod scaleway_k8s_v1_pool_upgrade_policy;
pub use self::scaleway_k8s_v1_pool_upgrade_policy::ScalewayK8sV1PoolUpgradePolicy;
pub mod scaleway_k8s_v1_runtime;
pub use self::scaleway_k8s_v1_runtime::ScalewayK8sV1Runtime;
pub mod scaleway_k8s_v1_version;
pub use self::scaleway_k8s_v1_version::ScalewayK8sV1Version;
pub mod scaleway_rdb_v1_acl_rule;
pub use self::scaleway_rdb_v1_acl_rule::ScalewayRdbV1AclRule;
pub mod scaleway_rdb_v1_acl_rule_action;
pub use self::scaleway_rdb_v1_acl_rule_action::ScalewayRdbV1AclRuleAction;
pub mod scaleway_rdb_v1_acl_rule_direction;
pub use self::scaleway_rdb_v1_acl_rule_direction::ScalewayRdbV1AclRuleDirection;
pub mod scaleway_rdb_v1_acl_rule_protocol;
pub use self::scaleway_rdb_v1_acl_rule_protocol::ScalewayRdbV1AclRuleProtocol;
pub mod scaleway_rdb_v1_acl_rule_request;
pub use self::scaleway_rdb_v1_acl_rule_request::ScalewayRdbV1AclRuleRequest;
pub mod scaleway_rdb_v1_add_instance_acl_rules_response;
pub use self::scaleway_rdb_v1_add_instance_acl_rules_response::ScalewayRdbV1AddInstanceAclRulesResponse;
pub mod scaleway_rdb_v1_add_instance_settings_response;
pub use self::scaleway_rdb_v1_add_instance_settings_response::ScalewayRdbV1AddInstanceSettingsResponse;
pub mod scaleway_rdb_v1_database;
pub use self::scaleway_rdb_v1_database::ScalewayRdbV1Database;
pub mod scaleway_rdb_v1_database_backup;
pub use self::scaleway_rdb_v1_database_backup::ScalewayRdbV1DatabaseBackup;
pub mod scaleway_rdb_v1_database_engine;
pub use self::scaleway_rdb_v1_database_engine::ScalewayRdbV1DatabaseEngine;
pub mod scaleway_rdb_v1_delete_instance_acl_rules_response;
pub use self::scaleway_rdb_v1_delete_instance_acl_rules_response::ScalewayRdbV1DeleteInstanceAclRulesResponse;
pub mod scaleway_rdb_v1_delete_instance_settings_response;
pub use self::scaleway_rdb_v1_delete_instance_settings_response::ScalewayRdbV1DeleteInstanceSettingsResponse;
pub mod scaleway_rdb_v1_endpoint;
pub use self::scaleway_rdb_v1_endpoint::ScalewayRdbV1Endpoint;
pub mod scaleway_rdb_v1_engine_setting;
pub use self::scaleway_rdb_v1_engine_setting::ScalewayRdbV1EngineSetting;
pub mod scaleway_rdb_v1_engine_setting_float_max;
pub use self::scaleway_rdb_v1_engine_setting_float_max::ScalewayRdbV1EngineSettingFloatMax;
pub mod scaleway_rdb_v1_engine_setting_float_min;
pub use self::scaleway_rdb_v1_engine_setting_float_min::ScalewayRdbV1EngineSettingFloatMin;
pub mod scaleway_rdb_v1_engine_version;
pub use self::scaleway_rdb_v1_engine_version::ScalewayRdbV1EngineVersion;
pub mod scaleway_rdb_v1_instance;
pub use self::scaleway_rdb_v1_instance::ScalewayRdbV1Instance;
pub mod scaleway_rdb_v1_instance_backup_schedule;
pub use self::scaleway_rdb_v1_instance_backup_schedule::ScalewayRdbV1InstanceBackupSchedule;
pub mod scaleway_rdb_v1_instance_endpoint;
pub use self::scaleway_rdb_v1_instance_endpoint::ScalewayRdbV1InstanceEndpoint;
pub mod scaleway_rdb_v1_instance_log;
pub use self::scaleway_rdb_v1_instance_log::ScalewayRdbV1InstanceLog;
pub mod scaleway_rdb_v1_instance_metrics;
pub use self::scaleway_rdb_v1_instance_metrics::ScalewayRdbV1InstanceMetrics;
pub mod scaleway_rdb_v1_instance_setting;
pub use self::scaleway_rdb_v1_instance_setting::ScalewayRdbV1InstanceSetting;
pub mod scaleway_rdb_v1_instance_volume;
pub use self::scaleway_rdb_v1_instance_volume::ScalewayRdbV1InstanceVolume;
pub mod scaleway_rdb_v1_list_database_backups_response;
pub use self::scaleway_rdb_v1_list_database_backups_response::ScalewayRdbV1ListDatabaseBackupsResponse;
pub mod scaleway_rdb_v1_list_database_engines_response;
pub use self::scaleway_rdb_v1_list_database_engines_response::ScalewayRdbV1ListDatabaseEnginesResponse;
pub mod scaleway_rdb_v1_list_databases_response;
pub use self::scaleway_rdb_v1_list_databases_response::ScalewayRdbV1ListDatabasesResponse;
pub mod scaleway_rdb_v1_list_instance_acl_rules_response;
pub use self::scaleway_rdb_v1_list_instance_acl_rules_response::ScalewayRdbV1ListInstanceAclRulesResponse;
pub mod scaleway_rdb_v1_list_instance_logs_response;
pub use self::scaleway_rdb_v1_list_instance_logs_response::ScalewayRdbV1ListInstanceLogsResponse;
pub mod scaleway_rdb_v1_list_instances_response;
pub use self::scaleway_rdb_v1_list_instances_response::ScalewayRdbV1ListInstancesResponse;
pub mod scaleway_rdb_v1_list_node_types_response;
pub use self::scaleway_rdb_v1_list_node_types_response::ScalewayRdbV1ListNodeTypesResponse;
pub mod scaleway_rdb_v1_list_privileges_response;
pub use self::scaleway_rdb_v1_list_privileges_response::ScalewayRdbV1ListPrivilegesResponse;
pub mod scaleway_rdb_v1_list_snapshots_response;
pub use self::scaleway_rdb_v1_list_snapshots_response::ScalewayRdbV1ListSnapshotsResponse;
pub mod scaleway_rdb_v1_list_users_response;
pub use self::scaleway_rdb_v1_list_users_response::ScalewayRdbV1ListUsersResponse;
pub mod scaleway_rdb_v1_node_type;
pub use self::scaleway_rdb_v1_node_type::ScalewayRdbV1NodeType;
pub mod scaleway_rdb_v1_node_type_volume_constraint;
pub use self::scaleway_rdb_v1_node_type_volume_constraint::ScalewayRdbV1NodeTypeVolumeConstraint;
pub mod scaleway_rdb_v1_node_type_volume_type;
pub use self::scaleway_rdb_v1_node_type_volume_type::ScalewayRdbV1NodeTypeVolumeType;
pub mod scaleway_rdb_v1_prepare_instance_logs_response;
pub use self::scaleway_rdb_v1_prepare_instance_logs_response::ScalewayRdbV1PrepareInstanceLogsResponse;
pub mod scaleway_rdb_v1_privilege;
pub use self::scaleway_rdb_v1_privilege::ScalewayRdbV1Privilege;
pub mod scaleway_rdb_v1_set_instance_acl_rules_response;
pub use self::scaleway_rdb_v1_set_instance_acl_rules_response::ScalewayRdbV1SetInstanceAclRulesResponse;
pub mod scaleway_rdb_v1_set_instance_settings_response;
pub use self::scaleway_rdb_v1_set_instance_settings_response::ScalewayRdbV1SetInstanceSettingsResponse;
pub mod scaleway_rdb_v1_snapshot;
pub use self::scaleway_rdb_v1_snapshot::ScalewayRdbV1Snapshot;
pub mod scaleway_rdb_v1_user;
pub use self::scaleway_rdb_v1_user::ScalewayRdbV1User;
pub mod scaleway_rdb_v1_volume_type;
pub use self::scaleway_rdb_v1_volume_type::ScalewayRdbV1VolumeType;
pub mod scaleway_registry_v1_image;
pub use self::scaleway_registry_v1_image::ScalewayRegistryV1Image;
pub mod scaleway_registry_v1_list_images_response;
pub use self::scaleway_registry_v1_list_images_response::ScalewayRegistryV1ListImagesResponse;
pub mod scaleway_registry_v1_list_namespaces_response;
pub use self::scaleway_registry_v1_list_namespaces_response::ScalewayRegistryV1ListNamespacesResponse;
pub mod scaleway_registry_v1_list_tags_response;
pub use self::scaleway_registry_v1_list_tags_response::ScalewayRegistryV1ListTagsResponse;
pub mod scaleway_registry_v1_namespace;
pub use self::scaleway_registry_v1_namespace::ScalewayRegistryV1Namespace;
pub mod scaleway_registry_v1_tag;
pub use self::scaleway_registry_v1_tag::ScalewayRegistryV1Tag;
pub mod scaleway_std_file;
pub use self::scaleway_std_file::ScalewayStdFile;
pub mod scaleway_std_service_info;
pub use self::scaleway_std_service_info::ScalewayStdServiceInfo;
pub mod scaleway_std_time_series;
pub use self::scaleway_std_time_series::ScalewayStdTimeSeries;
pub mod scaleway_std_time_series_point;
pub use self::scaleway_std_time_series_point::ScalewayStdTimeSeriesPoint;
pub mod scaleway_vpc_v1_list_private_networks_response;
pub use self::scaleway_vpc_v1_list_private_networks_response::ScalewayVpcV1ListPrivateNetworksResponse;
pub mod scaleway_vpc_v1_private_network;
pub use self::scaleway_vpc_v1_private_network::ScalewayVpcV1PrivateNetwork;
